@@ -1,4 +1,4 @@
-/* $Id: fm.h,v 1.3 2001/11/15 00:32:13 a-ito Exp $ */
+/* $Id: fm.h,v 1.29 2001/12/14 17:35:08 ukai Exp $ */
 /* 
  * w3m: WWW wo Miru utility
  * 
@@ -10,6 +10,11 @@
 #ifndef FM_H
 #define FM_H
 
+
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE		/* strcasestr() */
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -18,13 +23,13 @@
 #include "config.h"
 #include "history.h"
 
-#ifdef MENU
+#ifdef USE_MENU
 #define MENU_SELECT
 #define MENU_MAP
-#endif				/* MENU */
+#endif				/* USE_MENU */
 
-#ifndef COLOR
-#undef ANSI_COLOR
+#ifndef USE_COLOR
+#undef USE_ANSI_COLOR
 #endif
 
 #include "ctrlcode.h"
@@ -41,12 +46,13 @@
 #include "funcname1.h"
 #include "terms.h"
 
-#ifdef NOBCOPY
+#ifndef HAVE_BCOPY
 void bcopy(void *, void *, int);
 void bzero(void *, int);
-#else				/* not NOBCOPY */
-#include <string.h>
-#endif				/* not NOBCOPY */
+#endif				/* HAVE_BCOPY */
+#ifdef __EMX__
+#include <strings.h>		/* for bzero() and bcopy() */
+#endif
 
 #ifdef MAINPROGRAM
 #define global
@@ -89,10 +95,10 @@ void bzero(void *, int);
 #define SHELLBUFFERNAME	"*Shellout*"
 #define PIPEBUFFERNAME	"*stream*"
 #define CPIPEBUFFERNAME	"*stream(closed)*"
-#ifdef DICT
+#ifdef USE_DICT
 #define DICTCMD "w3mdict"
 #define DICTBUFFERNAME "*dictionary*"
-#endif				/* DICT */
+#endif				/* USE_DICT */
 
 /* 
  * Line Property
@@ -179,8 +185,7 @@ void bzero(void *, int);
 #define MAX_LB		5
 
 #ifdef MAINPROGRAM
-int REV_LB[MAX_LB] =
-{
+int REV_LB[MAX_LB] = {
     LB_N_FRAME, LB_FRAME, LB_N_INFO, LB_INFO, LB_N_SOURCE,
 };
 #else				/* not MAINPROGRAM */
@@ -229,7 +234,7 @@ extern int REV_LB[];
 #define free(x)  GC_free(x)	/* let GC do it. */
 
 #ifdef __EMX__
-#define STRCASECMP
+#define HAVE_STRCASECMP
 #define strcasecmp	stricmp
 #define strncasecmp	strnicmp
 #endif				/* __EMX__ */
@@ -254,7 +259,7 @@ extern int REV_LB[];
  */
 
 typedef unsigned short Lineprop;
-#ifdef ANSI_COLOR
+#ifdef USE_ANSI_COLOR
 typedef unsigned char Linecolor;
 #endif
 
@@ -268,7 +273,7 @@ typedef struct _MapList {
 typedef struct _Line {
     char *lineBuf;
     Lineprop *propBuf;
-#ifdef ANSI_COLOR
+#ifdef USE_ANSI_COLOR
     Linecolor *colorBuf;
 #endif
     struct _Line *next;
@@ -332,6 +337,8 @@ typedef struct _Buffer {
     short cursorY;
     short pos;
     short visualpos;
+    short rootX;
+    short COLS;
     InputStream pagerSource;
     AnchorList *href;
     AnchorList *name;
@@ -449,6 +456,7 @@ struct readbuffer {
 #define RB_IGNORE_P	0x4000
 #define RB_TITLE	0x8000
 #define RB_NFLUSHED	0x10000
+#define RB_NOFRAMES	0x20000
 
 #ifdef FORMAT_NICE
 #define RB_FILL		0x200000
@@ -540,21 +548,21 @@ struct cookie {
 #define COO_DOMAIN	4
 #define COO_PATH	8
 #define COO_DISCARD	16
-#define COO_OVERRIDE	32			/* user chose to override security checks */
+#define COO_OVERRIDE	32	/* user chose to override security checks */
 
-#define COO_OVERRIDE_OK	32			/* flag to specify that an error is overridable */
+#define COO_OVERRIDE_OK	32	/* flag to specify that an error is overridable */
 						/* version 0 refers to the original cookie_spec.html */
 						/* version 1 refers to RFC 2109 */
 						/* version 1' refers to the Internet draft to obsolete RFC 2109 */
-#define COO_EINTERNAL	(1)			/* unknown error; probably forgot to convert "return 1" in cookie.c */
+#define COO_EINTERNAL	(1)	/* unknown error; probably forgot to convert "return 1" in cookie.c */
 #define COO_ETAIL	(2 | COO_OVERRIDE_OK)	/* tail match failed (version 0) */
-#define COO_ESPECIAL	(3)			/* special domain check failed (version 0) */
-#define COO_EPATH	(4)			/* Path attribute mismatch (version 1 case 1) */
+#define COO_ESPECIAL	(3)	/* special domain check failed (version 0) */
+#define COO_EPATH	(4)	/* Path attribute mismatch (version 1 case 1) */
 #define COO_ENODOT	(5 | COO_OVERRIDE_OK)	/* no embedded dots in Domain (version 1 case 2.1) */
 #define COO_ENOTV1DOM	(6 | COO_OVERRIDE_OK)	/* Domain does not start with a dot (version 1 case 2.2) */
 #define COO_EDOM	(7 | COO_OVERRIDE_OK)	/* domain-match failed (version 1 case 3) */
 #define COO_EBADHOST	(8 | COO_OVERRIDE_OK)	/* dot in matched host name in FQDN (version 1 case 4) */
-#define COO_EPORT	(9)			/* Port match failed (version 1' case 5) */
+#define COO_EPORT	(9)	/* Port match failed (version 1' case 5) */
 #define COO_EMAX	COO_EPORT
 #endif				/* USE_COOKIE */
 
@@ -600,12 +608,11 @@ typedef struct http_request {
  */
 
 extern int LINES, COLS;
-#if defined(CYGWIN) && LANG == JA
-extern int isWinConsole;
-#define LASTLINE (LINES-(isWinConsole ? 2 : 1))
-#else				/* not defined(CYGWIN) && LANG == JA */
+#if defined(__CYGWIN__) && LANG == JA
+extern int LASTLINE;
+#else				/* not defined(__CYGWIN__) || LANG != JA */
 #define LASTLINE (LINES-1)
-#endif				/* not defined(CYGWIN) && LANG == JA */
+#endif				/* not defined(__CYGWIN__) || LANG != JA */
 
 global int Tabstop init(8);
 global int ShowEffect init(TRUE);
@@ -621,6 +628,7 @@ global char TargetSelf init(FALSE);
 global char PermitSaveToPipe init(FALSE);
 global char DecodeCTE init(FALSE);
 global char ArgvIsURL init(FALSE);
+global char MetaRefresh init(FALSE);
 
 global char fmInitialized init(FALSE);
 
@@ -629,10 +637,9 @@ extern char EscKeymap[];
 extern char EscBKeymap[];
 extern char EscDKeymap[];
 #ifdef __EMX__
-extern char	PcKeymap[];
+extern char PcKeymap[];
 #endif
 extern FuncList w3mFuncList[];
-extern KeyList w3mKeyList;
 
 global char *HTTP_proxy init(NULL);
 #ifdef USE_GOPHER
@@ -648,7 +655,7 @@ global char *NO_proxy init(NULL);
 global int NOproxy_netaddr init(TRUE);
 #ifdef INET6
 global int DNS_order init(0);
-extern int ai_family_order_table[3][3];		/* XXX */
+extern int ai_family_order_table[3][3];	/* XXX */
 #endif				/* INET6 */
 global TextList *NO_proxy_domains;
 global char NoCache init(FALSE);
@@ -665,12 +672,12 @@ global Buffer *Currentbuf;
 global Buffer *Firstbuf;
 global int CurrentKey;
 global char *CurrentKeyData;
-#ifdef MENU
+#ifdef USE_MENU
 global char *CurrentMenuData;
 #endif
 extern char *ullevel[];
 
-extern char *version;
+extern char *w3m_version;
 
 #define DUMP_BUFFER   0x01
 #define DUMP_HEAD     0x02
@@ -685,24 +692,40 @@ global int w3m_halfload init(FALSE);
 global Str header_string init(NULL);
 global int override_content_type init(FALSE);
 
-#ifdef COLOR
+#ifdef USE_COLOR
 global int useColor init(TRUE);
 global int basic_color init(8);	/* don't change */
 global int anchor_color init(4);	/* blue  */
 global int image_color init(2);	/* green */
 global int form_color init(1);	/* red   */
-#ifdef BG_COLOR
+#ifdef USE_BG_COLOR
 global int bg_color init(8);	/* don't change */
-#endif				/* BG_COLOR */
+#endif				/* USE_BG_COLOR */
 global int useActiveColor init(FALSE);
 global int active_color init(6);	/* cyan */
 global int useVisitedColor init(FALSE);
 global int visited_color init(5);	/* magenta  */
-#endif				/* COLOR */
+#endif				/* USE_COLOR */
 global int confirm_on_quit init(TRUE);
+#ifdef USE_MARK
+global int use_mark init(TRUE);
+#endif
+#ifdef EMACS_LIKE_LINEEDIT
+global int emacs_like_lineedit init(TRUE);
+#endif
+#ifdef VI_PREC_NUM
+global int vi_prec_num init(TRUE);
+#endif
+#ifdef LABEL_TOPLINE
+global int label_topline init(FALSE);
+#endif
+#ifdef NEXTPAGE_TOPLINE
+global int nextpage_topline init(FALSE);
+#endif
 global int displayLink init(FALSE);
 global int retryAsHttp init(TRUE);
 global int showLineNum init(FALSE);
+global int show_srch_str init(TRUE);
 global char *Editor init(DEF_EDITOR);
 global char *Mailer init(DEF_MAILER);
 global char *ExtBrowser init(DEF_EXT_BROWSER);
@@ -710,10 +733,15 @@ global char *ExtBrowser2 init(NULL);
 global char *ExtBrowser3 init(NULL);
 global int BackgroundExtViewer init(TRUE);
 global char *ftppasswd init(NULL);
+#ifdef FTPPASS_HOSTNAMEGEN
+global int ftppass_hostnamegen init(TRUE);
+#endif
 global int do_download init(FALSE);
 global char *UserAgent init(NULL);
 global int NoSendReferer init(FALSE);
 global char *AcceptLang init(NULL);
+global char *AcceptEncoding init(NULL);
+global char *AcceptMedia init(NULL);
 global int WrapDefault init(FALSE);
 global int IgnoreCase init(TRUE);
 global int WrapSearch init(FALSE);
@@ -722,12 +750,7 @@ global char *BookmarkFile init(NULL);
 global char *pauth init(NULL);
 global Str proxy_auth_cookie init(NULL);
 global int UseExternalDirBuffer init(TRUE);
-#ifdef __EMX__
-global char *DirBufferCommand init("file:///$LIB/dirlist.cmd");
-#else
-global char *DirBufferCommand init("file:///$LIB/dirlist.cgi");
-#endif				/* __EMX__ */
-global char *config_file init(NULL);
+global char *DirBufferCommand init("file:///$LIB/dirlist" CGI_EXTENSION);
 global int ignore_null_img_alt init(TRUE);
 
 global struct auth_cookie *Auth_cookie init(NULL);
@@ -736,10 +759,6 @@ global char *Local_cookie init(NULL);
 global struct cookie *First_cookie init(NULL);
 #endif				/* USE_COOKIE */
 
-global struct mailcap **UserMailcap;
-global struct table2 **UserMimeTypes;
-global TextList *mailcap_list;
-global TextList *mimetypes_list;
 global char *mailcap_files init(USER_MAILCAP ", " SYS_MAILCAP);
 global char *mimetypes_files init(USER_MIMETYPES ", " SYS_MIMETYPES);
 
@@ -782,11 +801,11 @@ extern char UseAltEntity;
 global char *rc_dir;
 global int rc_dir_is_tmp init(FALSE);
 
-#ifdef MOUSE
+#ifdef USE_MOUSE
 global int use_mouse init(TRUE);
 extern int mouseActive;
 global int reverse_mouse init(FALSE);
-#endif				/* MOUSE */
+#endif				/* USE_MOUSE */
 
 #ifdef USE_COOKIE
 global int default_use_cookie init(TRUE);
@@ -799,9 +818,7 @@ global TextList *Cookie_reject_domains;
 global TextList *Cookie_accept_domains;
 #endif				/* USE_COOKIE */
 
-#ifdef VIEW_UNSEENOBJECTS
 global int view_unseenobject init(TRUE);
-#endif				/* VIEW_UNSEENOBJECTS */
 
 #if defined(USE_SSL) && defined(USE_SSL_VERIFY)
 global int ssl_verify_server init(FALSE);
@@ -843,9 +860,16 @@ global int FollowRedirection init(10);
 global int w3m_backend init(FALSE);
 global Str backend_halfdump_str;
 global TextList *backend_batch_commands init(NULL);
-int backend( void );
+int backend(void);
 extern void deleteFiles(void);
-void w3m_exit( int i );
+void w3m_exit(int i);
+
+#ifdef USE_ALARM
+#define AL_UNSET         0
+#define AL_EXPLICIT      1
+#define AL_IMPLICIT      2
+#define AL_IMPLICIT_DONE 3
+#endif
 
 /* 
  * Externals
