@@ -1,4 +1,5 @@
-/* 
+/* $Id: func.c,v 1.7 2001/12/10 17:02:44 ukai Exp $ */
+/*
  * w3m func.c
  */
 
@@ -9,11 +10,10 @@
 #include "myctype.h"
 
 #include "funcname.c"
-int w3mNFuncList = 0;
+#include "functable.c"
 
-KeyList w3mKeyList = {
-    NULL, 0, 0
-};
+#define KEYDATA_HASH_SIZE 16
+static Hash_iv *keyData = NULL;
 
 void
 initKeymap(void)
@@ -24,9 +24,8 @@ initKeymap(void)
     int c;
     int f;
     int lineno;
-
-    if (!w3mNFuncList)
-	w3mNFuncList = countFuncList(w3mFuncList);
+    int verbose = 1;
+    extern int str_to_bool(char *value, int old);
 
     if ((kf = fopen(rcFile(KEYMAP_FILE), "rt")) == NULL)
 	return;
@@ -43,72 +42,68 @@ initKeymap(void)
 	s = getWord(&p);
 	if (*s == '#')		/* comment */
 	    continue;
-	if (strcmp(s, "keymap")) {	/* error */
-	    emsg = Sprintf("line %d: keymap not found\n", lineno)->ptr;
+	if (!strcmp(s, "keymap")) ;
+	else if (!strcmp(s, "verbose")) {
+	    s = getWord(&p);
+	    if (*s)
+		verbose = str_to_bool(s, verbose);
+	    continue;
+	}
+	else {			/* error */
+	    emsg = Sprintf("line %d: syntax error '%s'", lineno, s)->ptr;
 	    record_err_message(emsg);
-	    disp_message_nsec(emsg, FALSE, 1, TRUE, FALSE);
+	    if (verbose)
+		disp_message_nsec(emsg, FALSE, 1, TRUE, FALSE);
 	    continue;
 	}
 	s = getQWord(&p);
 	c = getKey(s);
 	if (c < 0) {		/* error */
-	    emsg = Sprintf("line %d: unknown key '%s'\n", lineno, s)->ptr;
+	    emsg = Sprintf("line %d: unknown key '%s'", lineno, s)->ptr;
 	    record_err_message(emsg);
-	    disp_message_nsec(emsg, FALSE, 1, TRUE, FALSE);
+	    if (verbose)
+		disp_message_nsec(emsg, FALSE, 1, TRUE, FALSE);
 	    continue;
 	}
 	s = getWord(&p);
-	f = getFuncList(s, w3mFuncList, w3mNFuncList);
+	f = getFuncList(s);
 	if (f < 0) {
-	    emsg = Sprintf("line %d: invalid command '%s'\n", lineno, s)->ptr;
+	    emsg = Sprintf("line %d: invalid command '%s'", lineno, s)->ptr;
 	    record_err_message(emsg);
-	    disp_message_nsec(emsg, FALSE, 1, TRUE, FALSE);
-	    f = FUNCNAME_nulcmd;
+	    if (verbose)
+		disp_message_nsec(emsg, FALSE, 1, TRUE, FALSE);
+	    continue;
 	}
 	if (c & K_ESCD)
-	    EscDKeymap[c ^ K_ESCD] = (f >= 0) ? f : FUNCNAME_nulcmd;
+	    EscDKeymap[c ^ K_ESCD] = f;
 	else if (c & K_ESCB)
-	    EscBKeymap[c ^ K_ESCB] = (f >= 0) ? f : FUNCNAME_nulcmd;
+	    EscBKeymap[c ^ K_ESCB] = f;
 	else if (c & K_ESC)
-	    EscKeymap[c ^ K_ESC] = (f >= 0) ? f : FUNCNAME_nulcmd;
+	    EscKeymap[c ^ K_ESC] = f;
 	else
-	    GlobalKeymap[c] = (f >= 0) ? f : FUNCNAME_nulcmd;
+	    GlobalKeymap[c] = f;
 	s = getQWord(&p);
-	addKeyList(&w3mKeyList, c, s);
+	if (*s) {
+	    if (keyData == NULL)
+		keyData = newHash_iv(KEYDATA_HASH_SIZE);
+	    putHash_iv(keyData, c, (void *)s);
+	}
     }
     fclose(kf);
 }
 
 int
-countFuncList(FuncList * list)
+getFuncList(char *id)
 {
-    int i;
-
-    for (i = 0; list->id != NULL; i++, list++);
-    return i;
+    return getHash_si(&functable, id, -1);
 }
 
-int
-getFuncList(char *id, FuncList * list, int nlist)
+char *
+getKeyData(int key)
 {
-    int i, is, ie, m;
-
-    if (id == NULL || *id == '\0' || nlist <= 0)
-	return -1;
-
-    is = 0;
-    ie = nlist - 1;
-    while (1) {
-	i = is + (ie - is) / 2;
-	if ((m = strcmp(id, list[i].id)) == 0)
-	    return i;
-	else if (is >= ie)
-	    return -1;
-	else if (m > 0)
-	    is = i + 1;
-	else
-	    ie = i - 1;
-    }
+    if (keyData == NULL)
+	return NULL;
+    return (char *)getHash_iv(keyData, key, NULL);
 }
 
 int
@@ -128,21 +123,19 @@ getKey(char *s)
     else if (strcasecmp(s, "LEFT") == 0)	/* ^[[D */
 	return K_ESCB | 'D';
 
-    if (strncasecmp(s, "ESC-", 4) == 0 ||
-	strncasecmp(s, "ESC ", 4) == 0) {	/* ^[ */
+    if (strncasecmp(s, "ESC-", 4) == 0 || strncasecmp(s, "ESC ", 4) == 0) {	/* ^[ */
 	s += 4;
 	esc = K_ESC;
     }
-    else if (strncasecmp(s, "M-", 2) == 0 ||
-	     strncasecmp(s, "\\E", 2) == 0) {	/* ^[ */
+    else if (strncasecmp(s, "M-", 2) == 0 || strncasecmp(s, "\\E", 2) == 0) {	/* ^[ */
 	s += 2;
 	esc = K_ESC;
     }
-    else if (*s == ESC_CODE) {			/* ^[ */
+    else if (*s == ESC_CODE) {	/* ^[ */
 	s++;
 	esc = K_ESC;
     }
-    if (strncasecmp(s, "C-", 2) == 0) {		/* ^, ^[^ */
+    if (strncasecmp(s, "C-", 2) == 0) {	/* ^, ^[^ */
 	s += 2;
 	ctrl = 1;
     }
@@ -171,11 +164,11 @@ getKey(char *s)
     }
 
     if (ctrl) {
-	if (*s >= '@' && *s <= '_')		/* ^@ .. ^_ */
+	if (*s >= '@' && *s <= '_')	/* ^@ .. ^_ */
 	    return esc | (*s - '@');
 	else if (*s >= 'a' && *s <= 'z')	/* ^a .. ^z */
 	    return esc | (*s - 'a' + 1);
-	else if (*s == '?')			/* ^? */
+	else if (*s == '?')	/* ^? */
 	    return esc | DEL_CODE;
 	else
 	    return -1;
@@ -229,46 +222,6 @@ getKey(char *s)
 	return -1;
 }
 
-void
-addKeyList(KeyList *list, int key, char *data)
-{
-    KeyListItem *item;
-
-    if (data == NULL || *data == '\0')
-	data = NULL;
-    else
-	data = allocStr(data, 0);
-    item = searchKeyList(list, key);
-    if (item == NULL) {
-	if (data == NULL)
-	    return;
-	list->nitem++;
-	if (list->nitem > list->size) {
-	    list->size = (list->size >= 2) ? (list->size * 3 / 2) : 2;
-	    list->item = New_Reuse(KeyListItem, list->item,
-		list->size * sizeof(KeyListItem));
-	}
-	item = &(list->item[list->nitem - 1]);
-	item->key = key;
-    }
-    item->data = data;
-}
-
-KeyListItem *
-searchKeyList(KeyList *list, int key)
-{
-    int i;
-    KeyListItem *item;
-
-    if (list == NULL)
-	return NULL;
-    for (i = 0, item = list->item; i < list->nitem; i++, item++) {
-	if (key == item->key)
-	    return item;
-    }
-    return NULL;
-}
-
 char *
 getWord(char **str)
 {
@@ -311,10 +264,8 @@ getQWord(char **str)
 		    *e++ = '\\';
 	    }
 	    else {
-		if (*p != '\\' && *p != '\'' &&		/* ..\\.., *
-							 * ..\'..  */
-		    *p != '"' && !IS_SPACE(*p))		/* ..\".., * ..\.. 
-							 */
+		if (*p != '\\' && *p != '\'' &&	/* ..\\.., ..\'.. */
+		    *p != '"' && !IS_SPACE(*p))	/* ..\".., ..\.. */
 		    *e++ = '\\';
 	    }
 	    *e++ = *p;
